summaryrefslogtreecommitdiff
path: root/pysnmp/hlapi/v3arch/asyncio/transport.py
diff options
context:
space:
mode:
Diffstat (limited to 'pysnmp/hlapi/v3arch/asyncio/transport.py')
-rw-r--r--pysnmp/hlapi/v3arch/asyncio/transport.py33
1 files changed, 17 insertions, 16 deletions
diff --git a/pysnmp/hlapi/v3arch/asyncio/transport.py b/pysnmp/hlapi/v3arch/asyncio/transport.py
index 9079c1c8..0b795163 100644
--- a/pysnmp/hlapi/v3arch/asyncio/transport.py
+++ b/pysnmp/hlapi/v3arch/asyncio/transport.py
@@ -16,27 +16,30 @@ __all__ = ['Udp6TransportTarget', 'UdpTransportTarget']
class UdpTransportTarget(AbstractTransportTarget):
- """Creates UDP/IPv4 configuration entry and initialize socket API if needed.
+ """Represent UDP/IPv6 transport endpoint.
- This object can be used for adding new entries to Local Configuration
- Datastore (LCD) managed by :py:class:`~pysnmp.hlapi.SnmpEngine`
+ This object can be used for passing UDP/IPv6 configuration
+ information to the
+ :py:class:`~pysnmp.hlapi.v3arch.asyncio.AsyncCommandGenerator` and
+ :py:class:`~pysnmp.hlapi.v3arch.asyncio.AsyncNotificationOriginator`
+ Datastore (LCD) managed by :py:class:`~pysnmp.hlapi.v3arch.SnmpEngine`
class instance.
See :RFC:`1906#section-3` for more information on the UDP transport mapping.
Parameters
----------
- transportAddr : tuple
+ transportAddr: tuple
Indicates remote address in Python :py:mod:`socket` module format
which is a tuple of FQDN, port where FQDN is a string representing
either hostname or IPv4 address in quad-dotted form, port is an
integer.
- timeout : int
+ timeout: int
Response timeout in seconds.
- retries : int
+ retries: int
Maximum number of request retries, 0 retries means just a single
request.
- tagList : str
+ tagList: str
Arbitrary string that contains a list of tag values which are used
to select target addresses for a particular operation
(:RFC:`3413#section-4.1.4`).
@@ -47,7 +50,6 @@ class UdpTransportTarget(AbstractTransportTarget):
>>> UdpTransportTarget(('demo.snmplabs.com', 161))
UdpTransportTarget(('195.218.195.228', 161), timeout=1, retries=5, tagList='')
>>>
-
"""
TRANSPORT_DOMAIN = udp.domainName
PROTO_TRANSPORT = udp.UdpAsyncioTransport
@@ -68,10 +70,10 @@ class Udp6TransportTarget(AbstractTransportTarget):
"""Creates UDP/IPv6 configuration entry and initialize socket API if needed.
This object can be used by
- :py:class:`~pysnmp.hlapi.asyncio.AsyncCommandGenerator` or
- :py:class:`~pysnmp.hlapi.asyncio.AsyncNotificationOriginator`
- and their derevatives for adding new entries to Local Configuration
- Datastore (LCD) managed by :py:class:`~pysnmp.hlapi.SnmpEngine`
+ :py:class:`~pysnmp.hlapi.v3arch.asyncio.AsyncCommandGenerator` or
+ :py:class:`~pysnmp.hlapi.v3arch.asyncio.AsyncNotificationOriginator`
+ and their derivatives for adding new entries to Local Configuration
+ Datastore (LCD) managed by :py:class:`~pysnmp.hlapi.v3arch.SnmpEngine`
class instance.
See :RFC:`1906#section-3`, :RFC:`2851#section-4` for more information
@@ -84,12 +86,12 @@ class Udp6TransportTarget(AbstractTransportTarget):
which is a tuple of FQDN, port where FQDN is a string representing
either hostname or IPv6 address in one of three conventional forms
(:RFC:`1924#section-3`), port is an integer.
- timeout : int
+ timeout: int
Response timeout in seconds.
- retries : int
+ retries: int
Maximum number of request retries, 0 retries means just a single
request.
- tagList : str
+ tagList: str
Arbitrary string that contains a list of tag values which are used
to select target addresses for a particular operation
(:RFC:`3413#section-4.1.4`).
@@ -108,7 +110,6 @@ class Udp6TransportTarget(AbstractTransportTarget):
>>> Udp6TransportTarget(('::', 161))
Udp6TransportTarget(('::', 161), timeout=1, retries=5, tagList='')
>>>
-
"""
TRANSPORT_DOMAIN = udp6.domainName
PROTO_TRANSPORT = udp6.Udp6AsyncioTransport